# AXAttributeConstants.h Documentation

## Overview
This header defines the string constants used to identify attributes of accessibility objects.

## Constants

| Constant Name | Description |
| :--- | :--- |
| `kAXAllowedValuesAttribute` | The list of allowed values for the accessibility object. |
| `kAXAMPMFieldAttribute` | The AM/PM field of a time field represented by this accessibility object. |
| `kAXCancelButtonAttribute` | The cancel button associated with the accessibility object. |
| `kAXChildrenAttribute` | An array of the accessibility object’s children. |
| `kAXCloseButtonAttribute` | The close button associated with the accessibility object. |
| `kAXColumnTitleAttribute` | The title of the column. |
| `kAXContentsAttribute` | The contents of the accessibility object. |
| `kAXDayFieldAttribute` | The day field of a time field. |
| `kAXDefaultButtonAttribute` | The default button associated with the accessibility object. |
| `kAXDescriptionAttribute` | A description of the accessibility object. |
| `kAXEnabledAttribute` | Indicates whether the accessibility object is enabled. |
| `kAXFocusedAttribute` | Indicates whether the accessibility object has focus. |
| `kAXGrowAreaAttribute` | The grow area of the window. |
| `kAXHeaderAttribute` | The header of the accessibility object. |
| `kAXHelpAttribute` | A localized string containing help text for this accessibility object. |
| `kAXHourFieldAttribute` | The hour field of a time field. |
| `kAXIncrementorAttribute` | The incrementor of a time or date field. |
| `kAXInsertionPointLineNumberAttribute` | The line number of the insertion point in the text. |
| `kAXMainAttribute` | Indicates whether the window is the main window. |
| `kAXMaxValueAttribute` | The maximum value this accessibility object can display. |
| `kAXMinimizeButtonAttribute` | The minimize button associated with the accessibility object. |
| `kAXMinimizedAttribute` | Indicates whether the window is currently minimized. |
| `kAXMinuteFieldAttribute` | The minute field of a time field. |
| `kAXMinValueAttribute` | The minimum value this accessibility object can display. |
| `kAXModalAttribute` | Indicates whether the window is modal. |
| `kAXMonthFieldAttribute` | The month field of a time field. |
| `kAXNumberOfCharactersAttribute` | The total number of characters in the editable text element. |
| `kAXOrientationAttribute` | The orientation of the accessibility object. |
| `kAXParentAttribute` | This accessibility object’s parent object. |
| `kAXPositionAttribute` | The position of the accessibility object. |
| `kAXProxyAttribute` | The proxy object for the accessibility object. |
| `kAXRoleAttribute` | The role, or type, of this accessibility object (e.g., AXButton). |
| `kAXRoleDescriptionAttribute` | A localized description of the accessibility object's role. |
| `kAXSecondFieldAttribute` | The second field of a time field. |
| `kAXSelectedChildrenAttribute` | The currently selected children. |
| `kAXSelectedTextAttribute` | The currently selected text within this accessibility object. |
| `kAXSelectedTextRangeAttribute` | The range of characters that defines the currently selected text. |
| `kAXSelectedTextRangesAttribute` | An array of selection ranges. |
| `kAXSharedCharacterRangeAttribute` | The shared character range. |
| `kAXSharedTextUIElementsAttribute` | The shared text UI elements. |
| `kAXSizeAttribute` | The vertical and horizontal dimensions of this accessibility object. |
| `kAXSubroleAttribute` | The subrole of the accessibility object. |
| `kAXTitleAttribute` | The title of the accessibility object. |
| `kAXToolbarButtonAttribute` | The toolbar button associated with the accessibility object. |
| `kAXTopLevelUIElementAttribute` | The top-level UI element (usually the window). |
| `kAXURLAttribute` | The URL that describes the location of the document or application. |
| `kAXValueAttribute` | The value of the accessibility object. |
| `kAXValueDescriptionAttribute` | A localized description of the value. |
| `kAXValueIncrementAttribute` | The amount the value changes as the result of a single action. |
| `kAXVisibleCharacterRangeAttribute` | The range of characters currently visible. |
| `kAXVisibleChildrenAttribute` | The children currently visible. |
| `kAXVisibleColumnsAttribute` | The columns currently visible in a browser view. |
| `kAXWindowAttribute` | The window containing the accessibility object. |
| `kAXYearFieldAttribute` | The year field of a time field. |
| `kAXZoomButtonAttribute` | The zoom button associated with the accessibility object. |
